@@ -1,13 +1,13 @@
-# Copyrights 2004,2006-2009 by Mark Overmeer.
+# Copyrights 2004,2006-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.02.
 use strict;
 use warnings;
 
 package Math::Polygon;
 use vars '$VERSION';
-$VERSION = '1.01';
+$VERSION = '1.04';
 
 
 use Math::Polygon::Calc;
@@ -74,6 +74,12 @@ sub area()
     $self->{MP_area} = polygon_area $self->points;
 }
 
+sub centroid()
+{   my $self = shift;
+    return $self->{MP_centroid} if $self->{MP_centroid};
+    $self->{MP_centroid} = polygon_centroid $self->points;
+}
+
 
 sub isClockwise()
 {   my $self = shift;
@@ -246,5 +252,4 @@ sub fillClip1($$$$)
 
 sub string() { polygon_string(shift->points) }
 
-
 1;
