@@ -1,13 +1,13 @@
-# Copyrights 2004,2006-2011 by Mark Overmeer.
+# Copyrights 2004,2006-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.02.
 use strict;
 use warnings;
 
 package Math::Polygon::Calc;
 use vars '$VERSION';
-$VERSION = '1.02';
+$VERSION = '1.04';
 
 use base 'Exporter';
 
@@ -32,15 +32,15 @@ use List::Util    qw/min max/;
 use Carp          qw/croak/;
 
 
-sub polygon_string(@) { join ', ', map { "[$_->[0],$_->[1]]" } @_ }
+sub polygon_string(@) { join ', ', map "[$_->[0],$_->[1]]", @_ }
 
 
 sub polygon_bbox(@)
 {
-    ( min( map {$_->[0]} @_ )
-    , min( map {$_->[1]} @_ )
-    , max( map {$_->[0]} @_ )
-    , max( map {$_->[1]} @_ )
+    ( min( map $_->[0], @_ )
+    , min( map $_->[1], @_ )
+    , max( map $_->[0], @_ )
+    , max( map $_->[1], @_ )
     );
 }
 
@@ -242,7 +242,7 @@ sub polygon_same($$;$)
 
 
 # Algorithms can be found at
-# http://astronomy.swin.edu.au/~pbourke/geometry/insidepoly/
+# http://www.eecs.umich.edu/courses/eecs380/HANDOUTS/PROJ2/InsidePoly.html
 # p1 = polygon[0];
 # for (i=1;i<=N;i++) {
 #   p2 = polygon[i % N];
@@ -275,10 +275,17 @@ sub polygon_contains_point($@)
 
     while(@_)
     {   my ($nx, $ny) = @{ (shift) };
+
+        # Extra check for exactly on the edge when the axes are
+        # horizontal or vertical.
         return 1 if $y==$py && $py==$ny
                  && ($x >= $px || $x >= $nx)
                  && ($x <= $px || $x <= $nx);
 
+        return 1 if $x==$px && $px==$nx
+                 && ($y >= $py || $y >= $ny)
+                 && ($y <= $py || $y <= $ny);
+
         if(   $py == $ny
            || ($y <= $py && $y <= $ny)
            || ($y >  $py && $y >  $ny)
@@ -289,8 +296,10 @@ sub polygon_contains_point($@)
             next;
         }
 
+        # side wrt diagonal
+        my $xinters = ($y-$py)*($nx-$px)/($ny-$py)+$px;
         $inside = !$inside
-            if $px==$nx || $x <= ($y-$py)*($nx-$px)/($ny-$py)+$px;
+            if $px==$nx || $x <= $xinters;
 
         ($px, $py) = ($nx, $ny);
     }
