@@ -1,7 +1,7 @@
-# Copyrights 2004,2006-2009 by Mark Overmeer.
+# Copyrights 2004,2006-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.02.
 # Algorithm by Dan Sunday
 # - http://geometryalgorithms.com/Archive/algorithm_0109/algorithm_0109.htm
 # Original implementation in Perl by Jari Turkia.
@@ -11,7 +11,7 @@ use warnings;
 
 package Math::Polygon::Convex;
 use vars '$VERSION';
-$VERSION = '1.01';
+$VERSION = '1.04';
 
 use base 'Exporter';
 
@@ -92,6 +92,12 @@ sub chainHull_2D(@)
     push @H, $P[$minmin]
         if $minmax != $minmin; # joining endpoint onto stack
 
+    # Remove duplicate points.
+    for(my $i = @H-1; $i > 1; $i--)
+    {   splice @H, $i, 1
+            while $H[$i][0]==$H[$i-1][0] && $H[$i][1]==$H[$i-1][1];
+    }
+
     Math::Polygon->new(@H);
 }
 
